@@ -8,7 +8,9 @@ function(fib.list, df, check=TRUE, length.out=500){
     stops <- max(fib.points[, 3])
     fb.df <- data.frame(x = fib.points[, 1], y = fib.points[,2], z = fib.points[, 3])
     newdata <- seq(starts, stops, length.out = length.out)
-    fit1 <- tryCatch(lm(cbind(x, y) ~ splines::ns(z, df = df), data = fb.df))
+    if(df==1){ fit1 <- tryCatch(lm(cbind(x,y)~z, data = fb.df))
+    } else {
+      fit1 <- tryCatch(lm(cbind(x,y)~nsp(z,df=df), data = fb.df))}
     fib.smoothed <- cbind(predict(fit1, newdata = list(z = newdata)), newdata)
     endr<-nrow(fib.smoothed)
     sl.dist[i]<-sqrt(sum((fib.smoothed[1,]-fib.smoothed[endr,])^2))
